)]}'
{
  "commit": "a2312b0153cde82285646da685853700ce29ae94",
  "tree": "b05bfae0478951462bcff525a9d8122c8966be64",
  "parents": [
    "c79fd24cfc38ba9850e1c7582bc2ed92238ed66e"
  ],
  "author": {
    "name": "Aniket Dhok",
    "email": "aniket.dhok@ittiam.com",
    "time": "Wed Apr 03 11:31:26 2019 +0530"
  },
  "committer": {
    "name": "Yunqing Wang",
    "email": "yunqingwang@google.com",
    "time": "Mon Apr 08 16:40:44 2019 +0000"
  },
  "message": "Optimize aom_quantize_b_adaptive module\n\nAdded AVX2 variant for aom_quantize_b_adaptive_c\n\nFor speed \u003d 3 and 4 presets observed encode time reduction of\n0.7% and 0.6%(averaged across multiple test cases).\n\nModule gains improved by factor of ~1.82x\non average w.r.t SSE2 variant.\n\nChange-Id: Ia403ae3547020699d59f009f8938ac13d8a4d7b6\n",
  "tree_diff": [
    {
      "type": "modify",
      "old_id": "abf6a605626c3527456c2a328fa6188347f96957",
      "old_mode": 33188,
      "old_path": "aom_dsp/aom_dsp.cmake",
      "new_id": "4829ee79c06bc6d3d1e39ca7dbc705b3ccacd409",
      "new_mode": 33188,
      "new_path": "aom_dsp/aom_dsp.cmake"
    },
    {
      "type": "modify",
      "old_id": "3be3c31950db04fc8d254e2d5cde3fd2cb8ae3ba",
      "old_mode": 33261,
      "old_path": "aom_dsp/aom_dsp_rtcd_defs.pl",
      "new_id": "a0ca999528da8c9edaee24ac91e66db521667f54",
      "new_mode": 33261,
      "new_path": "aom_dsp/aom_dsp_rtcd_defs.pl"
    },
    {
      "type": "add",
      "old_id": "0000000000000000000000000000000000000000",
      "old_mode": 0,
      "old_path": "/dev/null",
      "new_id": "33350871980f2c3b540356335c2b9e1577a1605c",
      "new_mode": 33188,
      "new_path": "aom_dsp/x86/adaptive_quantize_avx2.c"
    },
    {
      "type": "modify",
      "old_id": "51f2db81531d519e6092cd47d146c1cfaacc9506",
      "old_mode": 33188,
      "old_path": "test/quantize_func_test.cc",
      "new_id": "b705c79ff187f34ebfa87e92eb680f8a034de102",
      "new_mode": 33188,
      "new_path": "test/quantize_func_test.cc"
    }
  ]
}
